@@ -27,6 +27,7 @@ class QDBusInterface;
 class KProcess;
 class Python3Session : public PythonSession
 {
+    Q_OBJECT
   public:
     Python3Session(Cantor::Backend* backend);
 
@@ -39,12 +40,21 @@ class Python3Session : public PythonSession
 
   private:
     void runPythonCommand(const QString& command) const;
+    void runPythonCommandAsync(const QString& command);
+    void readExpressionOutput(const QString& commandProcessing);
+
     QString getOutput() const;
     QString getError() const;
 
+  private Q_SLOTS:
+    void onResultReady();
+
   private:
     QDBusInterface* m_pIface;
     KProcess* m_pProcess;
+
+  Q_SIGNALS:
+    void updateHighlighter();
 };
 
-#endif
\ No newline at end of file
+#endif
